/**
 * CMI : Cluster Method Invocation
 * Copyright (C) 2007-2008 Bull S.A.S.
 * Contact: cmi@ow2.org
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA
 * --------------------------------------------------------------------------
 * $Id:JNDIConfig.java 1124 2007-07-27 16:38:35Z loris $
 * --------------------------------------------------------------------------
 */

package org.ow2.cmi.config;

import java.util.HashSet;
import java.util.Set;


/**
 * Define the configuration of the JNDI implementation.
 * @author Loris Bouzonnet
 */
public final class JNDIConfig {

    /**
     * Set of protocol configurations.
     */
    private Set<ProtocolConfig> protocolConfigs = new HashSet<ProtocolConfig>();

    /**
     * The currently used protocol name.
     */
    private static String currentProtocolName;

    /**
     * @return the currently used protocol name
     */
    public static String getCurrentProtocolName() {
        return currentProtocolName;
    }

    /**
     * Set the currently used protocol name.
     * @param currentProtocolName the currently used protocol name
     */
    public static void setCurrentProtocolName(final String currentProtocolName) {
        JNDIConfig.currentProtocolName = currentProtocolName;
    }

    /**
     * @return the set of protocol configurations
     */
    public Set<ProtocolConfig> getProtocolConfigs() {
        return protocolConfigs;
    }

    /**
     * Add a protocol configurations.
     * @param protocolConfig a protocol configuration
     */
    public void addProtocolConfig(final ProtocolConfig protocolConfig) {
        protocolConfigs.add(protocolConfig);
    }

}
